# LittleMCMC Logo

The LittleMCMC logo was made with the [Namecheap Logo
Maker](https://www.namecheap.com/logo-maker/).

---

```
Hope you enjoy your new logo, here are the people that made your beautiful logo
happen :)

font name: Barlow-Black
font link: https://fonts.google.com/specimen/Barlow
font author: Jeremy Tribby
font author site: https://tribby.com/

icon designer: Leszek Pietrzak
icon designer link: https://thenounproject.com/magicznyleszek/

{"bg":"#156EAC","icon":"#F6575E","font":"#ffffff","slogan":"#ffffff"}
```
